# Composite Driver

`jumpstarter-driver-composite` provides functionality for interacting with composite devices.

## Installation

```bash
pip3 install --extra-index-url https://pkg.jumpstarter.dev/simple/ jumpstarter-driver-composite
```

## Configuration

Example configuration:

```yaml
export:
  composite:
    type: jumpstarter_driver_composite.driver.Composite
    config:
      # Add required config parameters here
```

## API Reference

Add API documentation here.
